==> openshift-model-machine-6.9.0-sources.jar: io/fabric8/openshift/api/model/machine/v1alpha1/RootVolumeFluent.java <==
package io.fabric8.openshift.api.model.machine.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RootVolumeFluent<A extends RootVolumeFluent<A>> extends BaseFluent<A>{
  public RootVolumeFluent() {
  }
  
  public RootVolumeFluent(RootVolume instance) {
    this.copyInstance(instance);
  }
  private String availabilityZone;
  private String deviceType;
  private Integer diskSize;
  private String sourceType;
  private String sourceUUID;
  private String volumeType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RootVolume instance) {
    instance = (instance != null ? instance : new RootVolume());
  
    if (instance != null) {
        this.withAvailabilityZone(instance.getAvailabilityZone());
        this.withDeviceType(instance.getDeviceType());
        this.withDiskSize(instance.getDiskSize());
        this.withSourceType(instance.getSourceType());
        this.withSourceUUID(instance.getSourceUUID());
        this.withVolumeType(instance.getVolumeType());
        this.withAvailabilityZone(instance.getAvailabilityZone());
        this.withDeviceType(instance.getDeviceType());
        this.withDiskSize(instance.getDiskSize());
        this.withSourceType(instance.getSourceType());
        this.withSourceUUID(instance.getSourceUUID());
        this.withVolumeType(instance.getVolumeType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAvailabilityZone() {
    return this.availabilityZone;
  }
  
  public A withAvailabilityZone(String availabilityZone) {
    this.availabilityZone=availabilityZone; return (A) this;
  }
  
  public boolean hasAvailabilityZone() {
    return this.availabilityZone != null;
  }
  
  public String getDeviceType() {
    return this.deviceType;
  }
  
  public A withDeviceType(String deviceType) {
    this.deviceType=deviceType; return (A) this;
  }
  
  public boolean hasDeviceType() {
    return this.deviceType != null;
  }
  
  public Integer getDiskSize() {
    return this.diskSize;
  }
  
  public A withDiskSize(Integer diskSize) {
    this.diskSize=diskSize; return (A) this;
  }
  
  public boolean hasDiskSize() {
    return this.diskSize != null;
  }
  
  public String getSourceType() {
    return this.sourceType;
  }
  
  public A withSourceType(String sourceType) {
    this.sourceType=sourceType; return (A) this;
  }
  
  public boolean hasSourceType() {
    return this.sourceType != null;
  }
  
  public String getSourceUUID() {
    return this.sourceUUID;
  }
  
  public A withSourceUUID(String sourceUUID) {
    this.sourceUUID=sourceUUID; return (A) this;
  }
  
  public boolean hasSourceUUID() {
    return this.sourceUUID != null;
  }
  
  public String getVolumeType() {
    return this.volumeType;
  }
  
  public A withVolumeType(String volumeType) {
    this.volumeType=volumeType; return (A) this;
  }
  
  public boolean hasVolumeType() {
    return this.volumeType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RootVolumeFluent that = (RootVolumeFluent) o;
    if (!java.util.Objects.equals(availabilityZone, that.availabilityZone)) return false;
  
    if (!java.util.Objects.equals(deviceType, that.deviceType)) return false;
  
    if (!java.util.Objects.equals(diskSize, that.diskSize)) return false;
  
    if (!java.util.Objects.equals(sourceType, that.sourceType)) return false;
  
    if (!java.util.Objects.equals(sourceUUID, that.sourceUUID)) return false;
  
    if (!java.util.Objects.equals(volumeType, that.volumeType)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(availabilityZone,  deviceType,  diskSize,  sourceType,  sourceUUID,  volumeType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (availabilityZone != null) { sb.append("availabilityZone:"); sb.append(availabilityZone + ","); }
    if (deviceType != null) { sb.append("deviceType:"); sb.append(deviceType + ","); }
    if (diskSize != null) { sb.append("diskSize:"); sb.append(diskSize + ","); }
    if (sourceType != null) { sb.append("sourceType:"); sb.append(sourceType + ","); }
    if (sourceUUID != null) { sb.append("sourceUUID:"); sb.append(sourceUUID + ","); }
    if (volumeType != null) { sb.append("volumeType:"); sb.append(volumeType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-machine-6.9.1-sources.jar: io/fabric8/openshift/api/model/machine/v1alpha1/RootVolumeFluent.java <==
package io.fabric8.openshift.api.model.machine.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RootVolumeFluent<A extends RootVolumeFluent<A>> extends BaseFluent<A>{
  public RootVolumeFluent() {
  }
  
  public RootVolumeFluent(RootVolume instance) {
    this.copyInstance(instance);
  }
  private String availabilityZone;
  private String deviceType;
  private Integer diskSize;
  private String sourceType;
  private String sourceUUID;
  private String volumeType;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RootVolume instance) {
    instance = (instance != null ? instance : new RootVolume());
    if (instance != null) {
          this.withAvailabilityZone(instance.getAvailabilityZone());
          this.withDeviceType(instance.getDeviceType());
          this.withDiskSize(instance.getDiskSize());
          this.withSourceType(instance.getSourceType());
          this.withSourceUUID(instance.getSourceUUID());
          this.withVolumeType(instance.getVolumeType());
          this.withAvailabilityZone(instance.getAvailabilityZone());
          this.withDeviceType(instance.getDeviceType());
          this.withDiskSize(instance.getDiskSize());
          this.withSourceType(instance.getSourceType());
          this.withSourceUUID(instance.getSourceUUID());
          this.withVolumeType(instance.getVolumeType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAvailabilityZone() {
    return this.availabilityZone;
  }
  
  public A withAvailabilityZone(String availabilityZone) {
    this.availabilityZone = availabilityZone;
    return (A) this;
  }
  
  public boolean hasAvailabilityZone() {
    return this.availabilityZone != null;
  }
  
  public String getDeviceType() {
    return this.deviceType;
  }
  
  public A withDeviceType(String deviceType) {
    this.deviceType = deviceType;
    return (A) this;
  }
  
  public boolean hasDeviceType() {
    return this.deviceType != null;
  }
  
  public Integer getDiskSize() {
    return this.diskSize;
  }
  
  public A withDiskSize(Integer diskSize) {
    this.diskSize = diskSize;
    return (A) this;
  }
  
  public boolean hasDiskSize() {
    return this.diskSize != null;
  }
  
  public String getSourceType() {
    return this.sourceType;
  }
  
  public A withSourceType(String sourceType) {
    this.sourceType = sourceType;
    return (A) this;
  }
  
  public boolean hasSourceType() {
    return this.sourceType != null;
  }
  
  public String getSourceUUID() {
    return this.sourceUUID;
  }
  
  public A withSourceUUID(String sourceUUID) {
    this.sourceUUID = sourceUUID;
    return (A) this;
  }
  
  public boolean hasSourceUUID() {
    return this.sourceUUID != null;
  }
  
  public String getVolumeType() {
    return this.volumeType;
  }
  
  public A withVolumeType(String volumeType) {
    this.volumeType = volumeType;
    return (A) this;
  }
  
  public boolean hasVolumeType() {
    return this.volumeType != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RootVolumeFluent that = (RootVolumeFluent) o;
    if (!java.util.Objects.equals(availabilityZone, that.availabilityZone)) return false;
    if (!java.util.Objects.equals(deviceType, that.deviceType)) return false;
    if (!java.util.Objects.equals(diskSize, that.diskSize)) return false;
    if (!java.util.Objects.equals(sourceType, that.sourceType)) return false;
    if (!java.util.Objects.equals(sourceUUID, that.sourceUUID)) return false;
    if (!java.util.Objects.equals(volumeType, that.volumeType)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(availabilityZone,  deviceType,  diskSize,  sourceType,  sourceUUID,  volumeType,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (availabilityZone != null) { sb.append("availabilityZone:"); sb.append(availabilityZone + ","); }
    if (deviceType != null) { sb.append("deviceType:"); sb.append(deviceType + ","); }
    if (diskSize != null) { sb.append("diskSize:"); sb.append(diskSize + ","); }
    if (sourceType != null) { sb.append("sourceType:"); sb.append(sourceType + ","); }
    if (sourceUUID != null) { sb.append("sourceUUID:"); sb.append(sourceUUID + ","); }
    if (volumeType != null) { sb.append("volumeType:"); sb.append(volumeType + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
